@@ -38,6 +38,8 @@ LANGUAGES = (
     ('fr', ugettext('French')),
     ('pl', ugettext('Polish')),
     ('pt', ugettext('Portugese')),
+    ('pt-br', ugettext('Brazilian Portuguese')),
+    ('es', ugettext('Spanish')),
 )
 
 SITE_ID = 1
