@@ -141,6 +141,6 @@ def get_datetime_now():
     """
     try:
         from django.utils import timezone
-        return timezone.now()
+        return timezone.now() # pragma: no cover
     except ImportError: # pragma: no cover
         return datetime.datetime.now()
